@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util::Config;
 
-our $DATE = '2015-04-09'; # DATE
-our $VERSION = '1.06'; # VERSION
+our $DATE = '2015-04-11'; # DATE
+our $VERSION = '1.07'; # VERSION
 
 use 5.010;
 use strict;
@@ -111,12 +111,12 @@ sub get_args_from_config {
     my %seen_profiles; # for debugging message
     for my $section (@sections) {
         my ($sect_scn, $sect_profile);
-        if ($section =~ /\A\w+\z/) {
-            $sect_scn = $section;
-        } elsif ($section =~ /\Aprofile=(.*)\z/) {
+        if ($section =~ /\Aprofile=(.*)\z/) {
             $sect_scn = 'GLOBAL';
             $sect_profile = $1;
-        } elsif ($section =~ /\A(\w+)\s+profile=(.*)\z/) {
+        } elsif ($section =~ /\A\S+\z/) {
+            $sect_scn = $section;
+        } elsif ($section =~ /\A(\S+)\s+profile=(.*)\z/) {
             $sect_scn = $1;
             $sect_profile = $2;
         } else {
@@ -192,7 +192,7 @@ Perinci::CmdLine::Util::Config - Utility routines related to config files
 
 =head1 VERSION
 
-This document describes version 1.06 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-09.
+This document describes version 1.07 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-11.
 
 =head1 FUNCTIONS
 
